# -*-sh-*- 
%define midasroot    /usr/local
%define midasversion 1.8.3
%define midasrelease 1
#
Name:    midas
Version: %{midasversion}
Release: %{midasrelease}
Source:  ftp://midas.triumf.ca/pub/midas/midas-%{midasversion}.tar.gz
Copyright: GPL
URL:http://midas.psi.ch
Icon:midas.xpm
Summary: Maximum Integrated Data Acquisition System (MIDAS) 
Group: Applications/Physics
BuildRoot: /tmp/root-midas
#
%description 
The Maximum Integrated Data Acquisition System (MIDAS) is a
general-purpose system for event based data acquisition in small and
medium scale physics experiments. It has been developed at the Paul
Scherrer Institute (Switzerland) and at TRIUMF (Canada) between 1993
and 1997 (Release of Version 1.0). Midas is based on a modular networking
capability and a central database system. MIDAS consists of a C library and
several applications. They run on many different operating systems such as
UNIX like, Windows NT, VxWorks, VMS and MS-DOS. While the system
is already in use in several laboratories, the development continues with new
features and tools. For the newest status, check the MIDAS home page 
http://midas.triumf.ca.
#

# ==========================================================
%prep
%setup0

# ==========================================================
%build 
make -s PREFIX=%{midasroot}

# ==========================================================
%install
make  -s install PREFIX=$RPM_BUILD_ROOT/%{midasroot}
# create a sample exptab
mkdir $RPM_BUILD_ROOT/etc
echo "# *** sample exptab for MIDAS ver. %{midasversion} *** "  >  $RPM_BUILD_ROOT/etc/exptab
echo "#exp  /home/daq exp"                                      >> $RPM_BUILD_ROOT/etc/exptab

# ==========================================================
%clean
rm -rf $RPM_BUILD_ROOT

# ==========================================================
%files
# doc
%attr(-, root, root) %doc README OVERVIEW

# necessary file to be part of the binary distribution
# tres will appear in the /usr/doc/midas-x.x.x-y 
%attr(644, root, root) %doc examples drivers
%attr(644, root, root) %doc doc utils

# config
%config(noreplace) /etc/exptab

# binaries
%attr(4711, root, root)  %{midasroot}/bin/dio
%attr( 711, root, root)  %{midasroot}/bin/lazylogger
%attr( 711, root, root)  %{midasroot}/bin/mcnaf
%attr( 711, root, root)  %{midasroot}/bin/mdump
%attr( 711, root, root)  %{midasroot}/bin/mhist
%attr( 711, root, root)  %{midasroot}/bin/mhttpd
%attr( 711, root, root)  %{midasroot}/bin/mlogger
%attr( 711, root, root)  %{midasroot}/bin/mlxspeaker
%attr( 711, root, root)  %{midasroot}/bin/mserver
%attr( 711, root, root)  %{midasroot}/bin/mstat
%attr( 711, root, root)  %{midasroot}/bin/mchart
%attr( 711, root, root)  %{midasroot}/bin/stripchart.tcl
%attr( 711, root, root)  %{midasroot}/bin/mtape
%attr( 711, root, root)  %{midasroot}/bin/odbedit
%attr( 711, root, root)  %{midasroot}/bin/odbhist
%attr( 711, root, root)  %{midasroot}/bin/elog
# libraries
%attr( 644, root, root)  %{midasroot}/lib/libmidas.a  
%attr( 755, root, root)  %{midasroot}/lib/libmidas.so
%attr( 644, root, root)  %{midasroot}/lib/mana.o
%attr( 644, root, root)  %{midasroot}/lib/mfe.o
# includes
%attr( 644, root, root)  %{midasroot}/include/*

# ==========================================================
%post
if [ "$1" = 1 ];then
    # change /etc/services
    if  ! grep midas /etc/services > /dev/null; then
	cp   /etc/services /etc/services.premidas
	cp   /etc/services /etc/services.tmp
	echo "midas 1175/tcp   # midas daq server"  >> /etc/services.tmp
	mv   /etc/services.tmp /etc/services 
	echo "midas......Install > /etc/services updated"
    fi
    # change /etc/inetd.conf
    if ! grep midas /etc/inetd.conf > /dev/null; then
	cp  /etc/inetd.conf /etc/inetd.conf.premidas
	cp  /etc/inetd.conf /etc/inetd.conf.tmp
	echo "#midas daq server" >> /etc/inetd.conf.tmp
	echo "midas stream tcp nowait root %{midasroot}/bin/mserver %{midasroot}/bin/mserver" >> /etc/inetd.conf.tmp
	mv /etc/inetd.conf.tmp /etc/inetd.conf
	echo "midas......Install > /etc/inetd.conf updated"
	pid=`ps -A | grep inet | awk '{print $1}'`
	kill -HUP $pid
	echo "midas......Install > Daemon inetd restarted"
    fi
    # change /etc/ld.so.conf
    if ! grep %{midasroot}/lib /etc/ld.so.conf > /dev/null; then
	cp  /etc/ld.so.conf /etc/ld.so.conf.premidas
	cp  /etc/ld.so.conf /etc/ld.so.conf.tmp
	echo "#midas so library location" >> /etc/ld.so.conf.tmp
	echo "%{midasroot}/lib" >> /etc/ld.so.conf.tmp
	mv /etc/ld.so.conf.tmp /etc/ld.so.conf
	/sbin/ldconfig
        echo "midas......Install > /etc/ld.so.conf updated"
    fi
    # Creates logical links
	ln -fs  %{midasroot}/bin/odbedit %{midasroot}/bin/odb
        echo "midas......Install > odb link done"
	ln -fs  %{midasroot}/bin/stripchart.tcl %{midasroot}/bin/stripchart
        echo "midas......Install > stripchart link done"
    ### done 
    echo "midas......Install > remember to edit /etc/exptab to include your experiment"
    echo " "
    echo "Check the midas web page for latest news."
    echo "http://midas.psi.ch or http://midas.triumf.ca"
    echo " "
fi

# ==========================================================
%postun
if [ "$1" = 0 ];then
    # change /etc/services
    if grep midas /etc/services > /dev/null ; then
	cp /etc/services /etc/services.tmp
	grep -v midas /etc/services > /etc/services.tmp
	mv /etc/services.tmp /etc/services
	echo "midas......Remove > /etc/services updated"
    fi
    # change /etc/inetd.conf
    if grep midas /etc/inetd.conf > /dev/null; then
	cp  /etc/inetd.conf /etc/inetd.conf.tmp
	grep -v midas /etc/inetd.conf >  /etc/inetd.conf.tmp
	mv /etc/inetd.conf.tmp /etc/inetd.conf
	pid=`ps -A | grep inet | awk '{print $1}'`
	echo "midas......Remove > /etc/inetd.conf updated"
	kill -HUP $pid
	echo "midas......Remove > Daemon inetd restarted"
    fi
    rm -f %{rootmidas}/bin/odb
    rm -f %{rootmidas}/bin/stripchart
fi

